summaryrefslogtreecommitdiff
path: root/lib/parser_aux.c
diff options
context:
space:
mode:
authorSimon Josefsson <simon@josefsson.org>2008-11-06 10:39:19 +0100
committerSimon Josefsson <simon@josefsson.org>2008-11-06 10:39:19 +0100
commitdba23430d153d7267c91996a9e2d23e49a792fd0 (patch)
treef1ebbe4f4485341f4078e4a8ae991d5f6cc9ea81 /lib/parser_aux.c
parent261769208ca5b4bfbd79bd31e7350e3200e20b2f (diff)
downloadlibtasn1-dba23430d153d7267c91996a9e2d23e49a792fd0.tar.gz
libtasn1-dba23430d153d7267c91996a9e2d23e49a792fd0.tar.bz2
libtasn1-dba23430d153d7267c91996a9e2d23e49a792fd0.zip
Fix LIBTASN1_VERSION namespace violation.
Diffstat (limited to 'lib/parser_aux.c')
-rw-r--r--lib/parser_aux.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/parser_aux.c b/lib/parser_aux.c
index 0f0f651..d1aa001 100644
--- a/lib/parser_aux.c
+++ b/lib/parser_aux.c
@@ -1139,7 +1139,7 @@ parse_version_string (const char *s, int *major, int *minor, int *micro)
* condition is not satisfied. If a %NULL is passed to this function,
* no check is done, but the version string is simply returned.
*
* See %LIBTASN1_VERSION for a suitable @req_version string.
*
* Return value: Version string of run-time library, or %NULL if the
* run-time library does not meet the required version number.
@@ -1147,7 +1147,7 @@ parse_version_string (const char *s, int *major, int *minor, int *micro)
const char *
asn1_check_version (const char *req_version)
{
- const char *ver = LIBTASN1_VERSION;
+ const char *ver = ASN1_VERSION;
int my_major, my_minor, my_micro;
int rq_major, rq_minor, rq_micro;
const char *my_plvl, *rq_plvl;
@@ -1139,7 +1139,7 @@ parse_version_string (const char *s, int *major, int *minor, int *micro)
* no check is done, but the version string is simply returned.
*
- * See %LIBTASN1_VERSION for a suitable @req_version string.
+ * See %ASN1_VERSION for a suitable @req_version string.
*
* Return value: Version string of run-time library, or %NULL if the